#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class Inertia(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Inertia
                | 
                | Represents the Inertia object.
                | The Inertia object can be associated with any relevant object of a document in
                | order to get or compute its inertia data. It takes into account all bodies of a
                | part.
                | 
                | This version allows you to compute the following data:
                | 
                |     mass
                |     density
                |     position of the center of gravity
                |     inertia matrix
                |     principal axes
                |     principal moments 
                | 
                | of a product.
                | 
                | The units are:
                | 
                |     Kilogram (Kg) for Mass
                |     Square meter (M^2) for Wet Area
                |     Cubic meter (M^3) for Volume
                |     Meter (M) for Position
                |     Square Kilogram meter ((KgM)^2) for Inertia Matrix and Principal
                |     Moments
                |     Kilogram per cubic meter (Kg/M^3) for Density 
                | 
                | The method GetTechnologicalObject("Inertia") on the product to analyze, allows
                | you to retrieve this object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.inertia = com_object

    @property
    def density(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Density() As double
                | 
                |     Returns or sets the density for the computation.
                | 
                |     The density value is set to:
                | 
                |         0: the computation must use densities attached to each
                |         object.
                |         any positive value: the computation has to use this value.
                |
                |     The density value is returned as:
                | 
                |         1: a default value is used (there is no density attached to
                |         objects).
                |         -1: the density is not homogeneous for each object.
                |         other positive values: the density attached to all objects.
                |
                |     Example:
                | 
                |              The first example gets the density of NewInertia
                |              inertia.
                |
                |             Dim ADensity As double
                |             ADensity = NewInertia.Density
                |
                |                 The second example sets the density of NewInertia
                |                 inertia.
                |
                |                 NewInertia.Density = 10.

        :rtype: float
        """

        return self.inertia.Density

    @density.setter
    def density(self, value: float):
        """
        :param float value:
        """

        self.inertia.Density = value

    @property
    def granularity_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GranularityMode() As long
                | 
                |     Returns or sets the Granularity Mode for Inertia
                |     Computation.
                | 
                |     The Granularity value is set to:
                | 
                |         0: Only main bodies option is selected => the computation must not use
                |         All bodies.
                |         1: Only main bodies option is not selected => the computation must use
                |         All bodies. 
                | 
                |     The Granularity value is returned as:
                | 
                |         0: the computation had considered only main bodies.
                |         1: the computation had not considered only main bodies.
                |         
                |     Example:
                | 
                |              The first example gets the Granularity of NewInertia
                |              inertia.
                |
                |             Dim AGranularityMode As Integer
                |             AGranularityMode = NewInertia.GranularityMode
                |
                |                 The second example sets the Granularity of NewInertia inertia
                |                 to deselect the "only main bodies".
                |
                |                 NewInertia.GranularityMode = 1

        :rtype: int
        """

        return self.inertia.GranularityMode

    @granularity_mode.setter
    def granularity_mode(self, value: int):
        """
        :param int value:
        """

        self.inertia.GranularityMode = value

    @property
    def mass(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Mass() As double (Read Only)
                | 
                |     Returns the mass.
                | 
                |     Example:
                | 
                |              This example retrieves the mass of NewInertia
                |              inertia.
                |
                |             Dim AMass As double
                |             AMass = NewInertia.Mass

        :rtype: float
        """

        return self.inertia.Mass

    def get_cog_position(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCOGPosition(CATSafeArrayVariant oCoordinates)
                | 
                |     Retrieves the position of the center of gravity.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             The position of the center of gravity with respect to the product
                |             coordinate system:
                | 
                |                 oCoordinates(0) is the X coordinate
                |                 oCoordinates(1) is the Y coordinate
                |                 oCoordinates(2) is the Z coordinate 
                | 
                |     Example:
                | 
                |              This example retrieves the position of the center of gravity of
                |              NewInertia inertia.
                |
                |             Dim Coordinates (2)
                |             NewInertia.GetCOGPosition Coordinates

        :rtype: tuple
        """

        vba_function_name = 'get_cog_position'
        vba_code = """
        Public Function get_cog_position(inertia)
            Dim oCoordinates (2)
            inertia.GetCOGPosition oCoordinates
            get_cog_position = oCoordinates
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_inertia_matrix(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetInertiaMatrix(CATSafeArrayVariant oMatrix)
                | 
                |     Retrieves the matrix of inertia.
                | 
                |     Parameters:
                | 
                |         oMatrix
                |             The matrix of inertia array:
                | 
                |                 oMatrix(0) is the Ixx component
                |                 oMatrix(1) is the Ixy component
                |                 oMatrix(2) is the Ixz component
                |                 oMatrix(3) is the Iyx component
                |                 oMatrix(4) is the Iyy component
                |                 oMatrix(5) is the Iyz component
                |                 oMatrix(6) is the Izx component
                |                 oMatrix(7) is the Izy component
                |                 oMatrix(8) is the Izz component 
                | 
                |     Example:
                | 
                |              This example retrieves the matrix of inertia of NewInertia
                |              inertia.
                |
                |             Dim Matrix (8)
                |             NewInertia.GetInertiaMatrix Matrix

        :rtype: tuple
        """

        vba_function_name = 'get_inertia_matrix'
        vba_code = """
        Public Function get_inertia_matrix(inertia)
            Dim oMatrix (8)
            inertia.GetInertiaMatrix oMatrix
            get_inertia_matrix = oMatrix
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_principal_axes(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPrincipalAxes(CATSafeArrayVariant oComponents)
                | 
                |     Retrieves the principal axes of inertia.
                | 
                |     Parameters:
                | 
                |         oComponents
                |             The principal axes of inertia array (A1, A2 and A3 are the
                |             principal axes of inertia):
                | 
                |                 oComponents(0) is the A1x component
                |                 oComponents(1) is the A2x component
                |                 oComponents(2) is the A3x component
                |                 oComponents(3) is the A1y component
                |                 oComponents(4) is the A2y component
                |                 oComponents(5) is the A3y component
                |                 oComponents(6) is the A1z component
                |                 oComponents(7) is the A2z component
                |                 oComponents(8) is the A3z component 
                | 
                |     Example:
                | 
                |              This example retrieves the principal axes of inertia of NewInertia
                |              inertia.
                |
                |             Dim Components (8)
                |             NewInertia.GetPrincipalAxes Components

        :rtype: tuple
        """
        vba_function_name = 'get_principal_axes'
        vba_code = """
        Public Function get_principal_axes(inertia)
            Dim oComponents(8)
            inertia.GetPrincipalAxes oComponents
            get_principal_axes = oComponents
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_principal_moments(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPrincipalMoments(CATSafeArrayVariant oValues)
                | 
                |     Retrieves the principal moments of inertia.
                | 
                |     Parameters:
                | 
                |         oValues
                |             The principal moments of inertia array:
                | 
                |                 oValues(0) is the M1 value with respect to the first principal
                |                 exes of inertia
                |                 oValues(1) is the M2 value with respect to the second principal
                |                 exes of inertia
                |                 oValues(2) is the M3 value with respect to the third principal
                |                 exes of inertia 
                | 
                |     Example:
                | 
                |              This example retrieves principal moments of inertia of NewInertia
                |              inertia.
                |
                |             Dim Values (2)
                |             NewInertia.GetPrincipalMoments Values

        :rtype: tuple
        """

        vba_function_name = 'get_principal_moments'
        vba_code = """
        Public Function get_principal_moments(inertia)
            Dim oValues (2)
            inertia.GetPrincipalMoments oValues
            get_principal_moments = oValues
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Inertia(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_adaptivity_manager import AnalysisAdaptivityManager
from pycatia.analysis_interfaces.analysis_cases import AnalysisCases
from pycatia.analysis_interfaces.analysis_mesh_manager import AnalysisMeshManager
from pycatia.analysis_interfaces.analysis_post_manager import AnalysisPostManager
from pycatia.analysis_interfaces.analysis_sets import AnalysisSets
from pycatia.system_interfaces.any_object import AnyObject


class AnalysisModel(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisModel
                | 
                | Represent the analysis model object.
                | Role: In the analysis document, an analysis model is the object dedicated to
                | set and manage all the required data for the discretization and idealization of
                | a Finite Element model.
                | This object gives access to:
                | 
                |     A collection of AnalysisCase.
                |     A collection of AnalysisSets (All the input sets like properties,
                |     groups).
                |     A AnalysisPostManager object for reporting.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_model = com_object

    @property
    def adaptivity_manager(self) -> AnalysisAdaptivityManager:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AdaptivityManager() As AnalysisAdaptivityManager (Read
                | Only)
                | 
                |     Returns the AdaptivityManager defined on the analysis
                |     model.
                | 
                |     Returns:
                |         a CATIAAnalysisAdaptivityManager.

        :rtype: AnalysisAdaptivityManager
        """

        return AnalysisAdaptivityManager(self.analysis_model.AdaptivityManager)

    @property
    def analysis_cases(self) -> AnalysisCases:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisCases() As AnalysisCases (Read Only)
                | 
                |     Returns the collection of analysis cases defined on the analysis
                |     model.
                | 
                |     Returns:
                |         oAnalysisCases Collection of cases.

        :rtype: AnalysisCases
        """

        return AnalysisCases(self.analysis_model.AnalysisCases)

    @property
    def analysis_sets(self) -> AnalysisSets:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisSets() As AnalysisSets (Read Only)
                | 
                |     Returns the analysis sets collection associated with a analysis
                |     model.
                | 
                |     Returns:
                |         a collection of CATIAAnalysisSets.

        :rtype: AnalysisSets
        """

        return AnalysisSets(self.analysis_model.AnalysisSets)

    @property
    def mesh_manager(self) -> AnalysisMeshManager:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MeshManager() As AnalysisMeshManager (Read Only)
                | 
                |     Returns the MeshManager defined on the analysis model.
                | 
                |     Returns:
                |         a CATIAAnalysisMeshManager.

        :rtype: AnalysisMeshManager
        """

        return AnalysisMeshManager(self.analysis_model.MeshManager)

    @property
    def post_manager(self) -> AnalysisPostManager:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PostManager() As AnalysisPostManager (Read Only)
                | 
                |     Returns the Postprocessing manager defined on the analysis
                |     model.
                | 
                |     Returns:
                |         oPostManager the AnalysisPostManager Object.

        :rtype: AnalysisPostManager
        """

        return AnalysisPostManager(self.analysis_model.PostManager)

    def run_transition(self, i_transition_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RunTransition(CATBSTR iTransitionName)
                | 
                |     Apply a transition to the analysis model.
                | 
                |     Parameters:
                | 
                |         Transition
                |             name.

        :param str i_transition_name:
        :rtype: None
        """
        return self.analysis_model.RunTransition(i_transition_name)

    def __repr__(self):
        return f'AnalysisModel(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class RenderingSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         RenderingSettingAtt
                | 
                | The interface to access a CATIARenderingSettingAtt.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rendering_setting_att = com_object

    @property
    def engine_interface(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EngineInterface() As CATBSTR
                | 
                |     Returns or sets the EngineInterface parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.rendering_setting_att.EngineInterface

    @engine_interface.setter
    def engine_interface(self, value: str):
        """
        :param str value:
        """

        self.rendering_setting_att.EngineInterface = value

    @property
    def output_height(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OutputHeight() As short
                | 
                |     Returns or sets the OutputHeight parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.rendering_setting_att.OutputHeight

    @output_height.setter
    def output_height(self, value: int):
        """
        :param int value:
        """

        self.rendering_setting_att.OutputHeight = value

    @property
    def output_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OutputPath() As CATBSTR
                | 
                |     Returns or sets the OutputPath parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.rendering_setting_att.OutputPath

    @output_path.setter
    def output_path(self, value: str):
        """
        :param str value:
        """

        self.rendering_setting_att.OutputPath = value

    @property
    def output_size_from(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OutputSizeFrom() As short
                | 
                |     Returns or sets the OutputSizeFrom parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is
                |     delegated.
                | 
                |     Parameters:
                | 
                |         OutputSizeFrom
                |             where to get the image size for a QuickRender. Legal
                |             values:
                |             1 : same size as viewpoint.
                |             2 : fixed size. Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.rendering_setting_att.OutputSizeFrom

    @output_size_from.setter
    def output_size_from(self, value: int):
        """
        :param int value:
        """

        self.rendering_setting_att.OutputSizeFrom = value

    @property
    def output_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OutputType() As short
                | 
                |     Returns or sets the OutputType parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is
                |     delegated.
                | 
                |     Parameters:
                | 
                |         OutputType
                |             where to save the image after a QuickRender. Legal
                |             values:
                |             1 : image saved to default file.
                |             2 : save image to specific file.

        :rtype: int
        """

        return self.rendering_setting_att.OutputType

    @output_type.setter
    def output_type(self, value: int):
        """
        :param int value:
        """

        self.rendering_setting_att.OutputType = value

    @property
    def output_width(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OutputWidth() As short
                | 
                |     Returns or sets the OutputWidth parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.rendering_setting_att.OutputWidth

    @output_width.setter
    def output_width(self, value: int):
        """
        :param int value:
        """

        self.rendering_setting_att.OutputWidth = value

    @property
    def save_auto_increment(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SaveAutoIncrement() As boolean
                | 
                |     Returns or sets the SaveAutoIncrement parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: bool
        """

        return self.rendering_setting_att.SaveAutoIncrement

    @save_auto_increment.setter
    def save_auto_increment(self, value: bool):
        """
        :param bool value:
        """

        self.rendering_setting_att.SaveAutoIncrement = value

    def get_engine_interface_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetEngineInterfaceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the EngineInterface
                |     parameter.
                |     Role:Retrieves the state of the EngineInterface parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rendering_setting_att.GetEngineInterfaceInfo(io_admin_level, io_locked)

    def get_output_height_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOutputHeightInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the OutputHeight
                |     parameter.
                |     Role:Retrieves the state of the OutputHeight parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rendering_setting_att.GetOutputHeightInfo(io_admin_level, io_locked)

    def get_output_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOutputPathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the OutputPath
                |     parameter.
                |     Role:Retrieves the state of the OutputPath parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rendering_setting_att.GetOutputPathInfo(io_admin_level, io_locked)

    def get_output_size_from_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOutputSizeFromInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the OutputSizeFrom
                |     parameter.
                |     Role:Retrieves the state of the OutputSizeFrom parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rendering_setting_att.GetOutputSizeFromInfo(io_admin_level, io_locked)

    def get_output_type_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOutputTypeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the OutputType
                |     parameter.
                |     Role:Retrieves the state of the OutputType parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rendering_setting_att.GetOutputTypeInfo(io_admin_level, io_locked)

    def get_output_width_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOutputWidthInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the OutputWidth
                |     parameter.
                |     Role:Retrieves the state of the OutputWidth parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rendering_setting_att.GetOutputWidthInfo(io_admin_level, io_locked)

    def get_save_auto_increment_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSaveAutoIncrementInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SaveAutoIncrement
                |     parameter.
                |     Role:Retrieves the state of the SaveAutoIncrement parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rendering_setting_att.GetSaveAutoIncrementInfo(io_admin_level, io_locked)

    def set_engine_interface_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetEngineInterfaceLock(boolean iLocked)
                | 
                |     Locks or unlocks the EngineInterface parameter.
                |     Role:Locks or unlocks the EngineInterface parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rendering_setting_att.SetEngineInterfaceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_engine_interface_lock'
        # # vba_code = """
        # # Public Function set_engine_interface_lock(rendering_setting_att)
        # #     Dim iLocked (2)
        # #     rendering_setting_att.SetEngineInterfaceLock iLocked
        # #     set_engine_interface_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_output_height_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOutputHeightLock(boolean iLocked)
                | 
                |     Locks or unlocks the OutputHeight parameter.
                |     Role:Locks or unlocks the OutputHeight parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rendering_setting_att.SetOutputHeightLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_output_height_lock'
        # # vba_code = """
        # # Public Function set_output_height_lock(rendering_setting_att)
        # #     Dim iLocked (2)
        # #     rendering_setting_att.SetOutputHeightLock iLocked
        # #     set_output_height_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_output_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOutputPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the OutputPath parameter.
                |     Role:Locks or unlocks the OutputPath parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rendering_setting_att.SetOutputPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_output_path_lock'
        # # vba_code = """
        # # Public Function set_output_path_lock(rendering_setting_att)
        # #     Dim iLocked (2)
        # #     rendering_setting_att.SetOutputPathLock iLocked
        # #     set_output_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_output_size_from_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOutputSizeFromLock(boolean iLocked)
                | 
                |     Locks or unlocks the OutputSizeFrom parameter.
                |     Role:Locks or unlocks the OutputSizeFrom parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rendering_setting_att.SetOutputSizeFromLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_output_size_from_lock'
        # # vba_code = """
        # # Public Function set_output_size_from_lock(rendering_setting_att)
        # #     Dim iLocked (2)
        # #     rendering_setting_att.SetOutputSizeFromLock iLocked
        # #     set_output_size_from_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_output_type_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOutputTypeLock(boolean iLocked)
                | 
                |     Locks or unlocks the OutputType parameter.
                |     Role:Locks or unlocks the OutputType parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rendering_setting_att.SetOutputTypeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_output_type_lock'
        # # vba_code = """
        # # Public Function set_output_type_lock(rendering_setting_att)
        # #     Dim iLocked (2)
        # #     rendering_setting_att.SetOutputTypeLock iLocked
        # #     set_output_type_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_output_width_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOutputWidthLock(boolean iLocked)
                | 
                |     Locks or unlocks the OutputWidth parameter.
                |     Role:Locks or unlocks the OutputWidth parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rendering_setting_att.SetOutputWidthLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_output_width_lock'
        # # vba_code = """
        # # Public Function set_output_width_lock(rendering_setting_att)
        # #     Dim iLocked (2)
        # #     rendering_setting_att.SetOutputWidthLock iLocked
        # #     set_output_width_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_save_auto_increment_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSaveAutoIncrementLock(boolean iLocked)
                | 
                |     Locks or unlocks the SaveAutoIncrement parameter.
                |     Role:Locks or unlocks the SaveAutoIncrement parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rendering_setting_att.SetSaveAutoIncrementLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_save_auto_increment_lock'
        # # vba_code = """
        # # Public Function set_save_auto_increment_lock(rendering_setting_att)
        # #     Dim iLocked (2)
        # #     rendering_setting_att.SetSaveAutoIncrementLock iLocked
        # #     set_save_auto_increment_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RenderingSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_linked_documents import AnalysisLinkedDocuments
from pycatia.analysis_interfaces.analysis_models import AnalysisModels
from pycatia.analysis_interfaces.analysis_sets import AnalysisSets
from pycatia.in_interfaces.document import Document
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.parameters import Parameters
from pycatia.knowledge_interfaces.relations import Relations
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class AnalysisManager(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisManager
                | 
                | Represents the root object inside an analysis document.
                | It aggregates all the objects making up an analysis document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_manager = com_object

    @property
    def analysis_models(self) -> AnalysisModels:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisModels() As AnalysisModels (Read Only)
                | 
                |     Returns the analysis model collection from the current analysis
                |     manager.
                | 
                |     Example:
                |         The following example returns from RootAnalysis the root analysis
                |         object of the active document, assumed to be an Analysis document, the
                |         collection of analysis models.
                | 
                |          Dim AnalysisDocument As Document
                |          Set AnalysisDocument = CATIA.ActiveDocument
                |          Dim RootAnalysis As AnalysisManager
                |          Set RootAnalysis = AnalysisDocument.Analysis
                |          Dim analysisModels As AnalysisModels
                |          Set analysisModels = RootAnalysis.AnalysisModels

        :rtype: AnalysisModels
        """

        return AnalysisModels(self.analysis_manager.AnalysisModels)

    @property
    def analysis_sets(self) -> AnalysisSets:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisSets() As AnalysisSets (Read Only)
                | 
                |     Returns the analysis sets collection associated with an analysis manager.
                |     This collection allows to access the Analysis Connection Manager that
                |     aggregates the Analysis Connection features.
                | 
                |     Returns:
                |         a collection of CATIAAnalysisSets.

        :rtype: AnalysisSets
        """

        return AnalysisSets(self.analysis_manager.AnalysisSets)

    @property
    def linked_documents(self) -> AnalysisLinkedDocuments:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LinkedDocuments() As AnalysisLinkedDocuments (Read
                | Only)
                | 
                |     Returns the collection containing the documents linked to analysis
                |     document. All the CATIA documents that are linked to the different objects
                |     (like AnalysisMeshPart of Analysis Entity) might be accessed thru that
                |     collection.
                | 
                |     Example:
                |         The following example returns in documents the linked documents of the
                |         AnalysisDocument :
                | 
                |          Dim AnalysisDocument As Document
                |          Set AnalysisDocument = CATIA.ActiveDocument
                |          Dim RootAnalysis As AnalysisManager
                |          Set RootAnalysis = AnalysisDocument.Analysis
                |          Dim Documents As AnalysisLinkedDocuments
                |          Set Documents = RootAnalysis.LinkedDocuments

        :rtype: AnalysisLinkedDocuments
        """

        return AnalysisLinkedDocuments(self.analysis_manager.LinkedDocuments)

    @property
    def parameters(self) -> Parameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Parameters() As Parameters (Read Only)
                | 
                |     Returns the collection object containing the analysis parameters. All the
                |     parameters that are defined in analysis objects might be accessed thru that
                |     collection.
                | 
                |     Example:
                |         The following example returns in params the parameters of the
                |         RootAnalysis from the AnalysisDocument document:
                | 
                |          Dim AnalysisDocument As Document
                |          Set AnalysisDocument = CATIA.ActiveDocument
                |          Dim RootAnalysis As AnalysisManager
                |          Set RootAnalysis = AnalysisDocument.Analysis
                |          Dim params As CATIAParameters
                |          Set params = RootAnalysis.Parameters

        :rtype: Parameters
        """

        return Parameters(self.analysis_manager.Parameters)

    @property
    def relations(self) -> Relations:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Relations() As Relations (Read Only)
                | 
                |     Returns the collection object containing the analysis relations. All the
                |     relations that are defined in analysis objects might be accessed thru that
                |     collection.
                | 
                |     Example:
                |         The following example returns in relation the relations of the
                |         RootAnalysis from the AnalysisDocument document:
                | 
                |          Dim AnalysisDocument As Document
                |          Set AnalysisDocument = CATIA.ActiveDocument
                |          Dim RootAnalysis As AnalysisManager
                |          Set RootAnalysis = AnalysisDocument.Analysis
                |          Dim relation As CATIARelations
                |          Set relation = RootAnalysis.Relations

        :rtype: Relations
        """

        return Relations(self.analysis_manager.Relations)

    def create_reference_from_geometry(self, i_product: Product, i_geometry: Reference) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateReferenceFromGeometry(Product iProduct,
                | Reference iGeometry) As Reference
                | 
                |     Creates a reference from a geometry. This geometry must in defined in a
                |     document rerecened in the CATIAAnalysisLinkedDocuments
                |     collection.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product of the geometry to be referenced that defines the
                |             instance of the geometry. 
                |         iGeometry
                |             The geometry to be referenced. As a reference, it can be an
                |             CATIABoundary object of a mechanical feature. 
                | 
                |     Returns:
                |         a reference of the couple (iProduct, iGeometry).

        :param Product i_product:
        :param Reference i_geometry:
        :rtype: Reference
        """
        return Reference(self.analysis_manager.CreateReferenceFromGeometry(i_product.com_object, i_geometry.com_object))

    def create_reference_from_object(self, i_object: AnyObject) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateReferenceFromObject(AnyObject iObject) As
                | Reference
                | 
                |     Creates a reference from an analysis object. Use of reference allows a
                |     uniform handling of anay objects.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The analysis object to be referenced. It can be an AnalysisEntity
                |             or an AnalysisSet 
                | 
                |     Returns:
                |         The reference to the object.

        :param AnyObject i_object:
        :rtype: Reference
        """
        return Reference(self.analysis_manager.CreateReferenceFromObject(i_object.com_object))

    def import_(self, i_document_to_import: Document) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Import(Document iDocumentToImport)
                | 
                |     Import an existing document in an analysis document . This document can of
                |     any type that implement the CATIADocument interface. This is implemented for
                |     internal document formats. (like Part or Product
                |     documents).
                | 
                |     Example:
                |         The following example imports an opened CATPart
                |         document
                | 
                |          Dim AnalysisDocument As Document
                |          Dim PartDocument As Document
                |          Set AnalysisDocument = CATIA.ActiveDocument
                |          Dim RootAnalysis As AnalysisManager
                |          Set RootAnalysis = AnalysisDocument.Analysis
                |          RootAnalysis.Import(PartDocument)

        :param Document i_document_to_import:
        :rtype: None
        """
        return self.analysis_manager.Import(i_document_to_import.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'import'
        # # vba_code = """
        # # Public Function import(analysis_manager)
        # #     Dim iDocumentToImport (2)
        # #     analysis_manager.Import iDocumentToImport
        # #     import = iDocumentToImport
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def import_define_file(self, i_document_path: str, i_type_late: str, i_values: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ImportDefineFile(CATBSTR iDocumentPath,
                | CATBSTR iTypeLate,
                | CATSafeArrayVariant iValues)
                | 
                |     Import an existing document in an analysis document. This document can of
                |     any type that is managed by the CATISamImportDefine
                |     interface.
                | 
                |     Example:
                |         The following example imports an CATPart document stored as FileToOpen
                |         file. This example is also use the CATAnalysisImport Object. This object allow
                |         to import Part, Product or Analysis documents. As of today no parameters are
                |         mandatory for this object.
                | 
                |          Dim arrayOfVariant(0)
                |          FileToOpen = "e:/users/Parts/ThisIsANicePart.CATPart"
                |          ObjectForImport = "CATAnalysisImport"
                |          Dim AnalysisDocument As Document
                |          Set AnalysisDocument = CATIA.ActiveDocument
                |          Dim RootAnalysis As AnalysisManager
                |          Set RootAnalysis = AnalysisDocument.Analysis
                |          RootAnalysis.ImportDefineFile(FileToOpen,CATAnalysisImport,arrayOfVariant)

        :param str i_document_path:
        :param str i_type_late:
        :param tuple i_values:
        :rtype: None
        """
        return self.analysis_manager.ImportDefineFile(i_document_path, i_type_late, i_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'import_define_file'
        # # vba_code = """
        # # Public Function import_define_file(analysis_manager)
        # #     Dim iDocumentPath (2)
        # #     analysis_manager.ImportDefineFile iDocumentPath
        # #     import_define_file = iDocumentPath
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def import_file(self, i_document_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ImportFile(CATBSTR iDocumentPath)
                | 
                |     Import an existing document in an analysis document.
                | 
                |     Deprecated:
                |         V5R15 use ImportDefineFile instead. This document can of any type that
                |         implement the CATISamImportDefine interface.
                | 
                |         Example:
                |             The following example imports an CATPart document stored as
                |             FileToOpen file.
                | 
                |              FileToOpen = "e:/users/Parts/ThisIsANicePart.CATPart"
                |              Dim AnalysisDocument As Document
                |              Set AnalysisDocument = CATIA.ActiveDocument
                |              Dim RootAnalysis As AnalysisManager
                |              Set RootAnalysis = AnalysisDocument.Analysis
                |              RootAnalysis.ImportFile(FileToOpen)

        :param str i_document_path:
        :rtype: None
        """
        return self.analysis_manager.ImportFile(i_document_path)

    def __repr__(self):
        return f'AnalysisManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.navigator_interfaces.annotated_views import AnnotatedViews
from pycatia.navigator_interfaces.group import Group
from pycatia.navigator_interfaces.marker_3Ds import Marker3Ds
from pycatia.space_analyses_interfaces.conflicts import Conflicts
from pycatia.system_interfaces.any_object import AnyObject


class Clash(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Clash
                | 
                | Represents the Clash object.
                | The Clash object is a specification of a collision detection of
                | products.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.clash = com_object

    @property
    def annotated_views(self) -> AnnotatedViews:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AnnotatedViews() As AnnotatedViews (Read Only)
                | 
                |     Returns the AnnotatedViews collection of the clash.
                | 
                |     Example:
                | 
                |              This example retrieves the AnnotatedViews collection of NewClash
                |              Clash.
                |
                |             Dim TheAnnotatedViewsList As AnnotatedViews
                |             Set TheAnnotatedViewsList = NewClash.AnnotatedViews

        :rtype: AnnotatedViews
        """

        return AnnotatedViews(self.clash.AnnotatedViews)

    @property
    def clearance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Clearance() As double
                | 
                |     Returns or sets the clearance value for the computation.
                | 
                |     The clearance value must be greater than 0. Units are
                |     Millimeter.
                | 
                |     Example:
                | 
                |              The first example retrieves the clearance value of NewClash
                |              Clash.
                |
                |             Dim Value As double
                |             Value = NewClash.Clearance
                |
                |                 The second example sets the clearance value of NewClash
                |                 Clash.
                |
                |                 NewClash.Clearance = 10.

        :rtype: float
        """

        return self.clash.Clearance

    @clearance.setter
    def clearance(self, value: float):
        """
        :param float value:
        """

        self.clash.Clearance = value

    @property
    def computation_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ComputationType() As CatClashComputationType
                | 
                |     Returns or sets the computation type.
                | 
                |     Example:
                | 
                |             The first example retrieves the computation type of NewClash
                |             Clash.
                |             
                |             Dim ComputationType As CatClashComputationType
                |             ComputationType = NewClash.ComputationType
                |
                |            The second example sets the computation type of NewClash
                |            Clash.
                |
                |            NewClash.ComputationType = catClashComputationTypeBetweenAll

        :return: enum cat_clash_computation_type
        :rtype: int
        """

        return self.clash.ComputationType

    @computation_type.setter
    def computation_type(self, value: int):
        """
        :param int value: enum cat_clash_computation_type
        """

        self.clash.ComputationType = value

    @property
    def conflicts(self) -> Conflicts:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Conflicts() As Conflicts (Read Only)
                | 
                |     Returns the collection of computed Conflicts.
                | 
                |     Example:
                | 
                |              This example retrieves the conflicts of NewClash
                |              Clash.
                |
                |             Dim NewConflicts As Conflicts
                |             Set NewConflicts = NewClash.Conflicts

        :rtype: Conflicts
        """

        return Conflicts(self.clash.Conflicts)

    @property
    def first_group(self) -> Group:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstGroup() As Group
                | 
                |     Returns or sets the first group used by the computation.
                | 
                |     Example:
                | 
                |              The first example retrieves the first group of NewClash
                |              Clash.
                |             
                |             Dim FirstGroup As Group
                |             Set FirstGroup = NewClash.FirstGroup
                |
                |                 The second example sets the first  group of NewClash
                |                 Clash.
                |
                |                 Dim FirstGroup As Group
                |                 NewClash.FirstGroup = FirstGroup

        :rtype: Group
        """

        return Group(self.clash.FirstGroup)

    @first_group.setter
    def first_group(self, group: Group):
        """
        :param Group group:
        """

        self.clash.FirstGroup = group.com_object

    @property
    def interference_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InterferenceType() As CatClashInterferenceType
                | 
                |     Returns or sets the interference type for the computation.
                | 
                |     Example:
                | 
                |              The first example retrieves the interference type of NewClash
                |              Clash.
                |             
                | 
                |             Dim InterferenceType As CatClashInterferenceType
                |             InterferenceType = NewClash.InterferenceType
                |
                |                 The second example sets the interference Type of NewClash
                |                 Clash.
                |
                |                 NewClash.InterferenceType = CatClashInterferenceTypeContact

        :return: enum cat_clash_interference_type
        :rtype: int
        """

        return self.clash.InterferenceType

    @interference_type.setter
    def interference_type(self, value: int):
        """
        :param int value:
        """

        self.clash.InterferenceType = value

    @property
    def marker_3ds(self) -> Marker3Ds:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Marker3Ds() As Marker3Ds (Read Only)
                | 
                |     Returns the Marker3Ds collection of the clash.
                | 
                |     Example:
                | 
                |              This example retrieves the Marker3Ds collection of NewClash
                |              Clash.
                |
                |             Dim TheMarker3DsList As Marker3Ds
                |             Set TheMarker3DsList = NewClash.Marker3Ds

        :rtype: Marker3Ds
        """

        return Marker3Ds(self.clash.Marker3Ds)

    @property
    def second_group(self) -> Group:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondGroup() As Group
                | 
                |     Returns or sets the second group used by the computation.
                | 
                |     Example:
                | 
                |              The first example retrieves the second group of NewClash
                |              Clash.
                |
                |             Dim SecondGroup As Group
                |             Set SecondGroup = NewClash.SecondGroup
                |
                |                 The second example sets the second group of NewClash
                |                 Clash.
                |
                |                 Dim SecondGroup As Group
                |                 NewClash.SecondGroup = SecondGroup

        :rtype: Group
        """

        return Group(self.clash.SecondGroup)

    @second_group.setter
    def second_group(self, group: Group):
        """
        :param Group group:
        """

        self.clash.SecondGroup = group.com_object

    def compute(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Compute()
                | 
                |     Computes the conflicts.
                | 
                |     Example:
                | 
                |              This example computes the conflicts of NewClash
                |              Clash.
                |
                |             NewClash.Compute

        :rtype: None
        """
        return self.clash.Compute()

    def export(self, i_type: int, i_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Export(CatClashExportType iType,
                | CATBSTR iPath)
                | 
                |     Exports the results in a XML file.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of export. 
                |         iPath
                |             The path of the file. 
                | 
                |     Example:
                | 
                |              This example exports the results of NewClash
                |              Clash.
                |
                |             Dim ThePath As String
                |             NewClash.Export CatClashExportTypeXMLResultOnly,
                |             "c:\\tmp\\sample.xml"

        :param int i_type: enum cat_clash_export_type
        :param str i_path:
        :rtype: None
        """
        return self.clash.Export(i_type, i_path)

    def __repr__(self):
        return f'Clash(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.general_knowledge_interfaces.expert_rule_set import ExpertRuleSet
from pycatia.knowledge_interfaces.relation import Relation
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.general_knowledge_interfaces.expert_rule_base import ExpertRuleBase


class ExpertRuleBaseRuntime(Relation):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.KnowledgeObject
                |                        KnowledgeInterfaces.KnowledgeActivateObject
                |                             KnowledgeInterfaces.Relation
                |                                 ExpertRuleBaseRuntime
                | 
                | Represents the Runtime part of the RuleBase.
                | The following example shows how to create the Rule Base RB1 from a newly
                | created part document:
                | 
                |  Dim CATDocs As Document
                |  Set CATDocs   = CATIA.Documents
                |  Dim partdoc As PartDocument
                |  Set partdoc   = CATDocs.Add("CATPart")
                |  Dim part As Part
                |  Set part      = partdoc.Part
                |  Dim relations As Relations
                |  Set relations = part.Relations
                |  Dim Rulebase As ExpertRuleBaseRuntime
                |  Set RuleBase  = relations.CreateRuleBase("RB1")
                |
                | See also:
                |     Relations
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.expert_rule_base_runtime = com_object

    @property
    def report_description_length(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReportDescriptionLength() As
                | CatDescriptionLengthType
                | 
                |     Returns or sets the Report Description Length (For Text option
                |     only).
                | 
                |     0
                |         ShortText 
                |     1
                |         LongText

        :return: enum cat_description_length_type
        :rtype: int
        """

        return self.expert_rule_base_runtime.ReportDescriptionLength

    @report_description_length.setter
    def report_description_length(self, value: int):
        """
        :param int value: enum cat_description_length_type
        """

        self.expert_rule_base_runtime.ReportDescriptionLength = value

    @property
    def report_output_format(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReportOutPutFormat() As CatOutPutFormatType
                | 
                |     Returns or sets the Report OutPut Format.
                | 
                |     0
                |         Html 
                |     1
                |         Text 
                |     2
                |         Print 
                |     3
                |         Email

        :return: enum cat_out_put_format_type
        :rtype: int
        """

        return self.expert_rule_base_runtime.ReportOutPutFormat

    @report_output_format.setter
    def report_output_format(self, value: int):
        """
        :param int value: enum cat_out_put_format_type
        """

        self.expert_rule_base_runtime.ReportOutPutFormat = value

    @property
    def report_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReportPath() As CATBSTR
                | 
                |     Returns or sets the Report output path.

        :rtype: str
        """

        return self.expert_rule_base_runtime.ReportPath

    @report_path.setter
    def report_path(self, value: str):
        """
        :param str value:
        """

        self.expert_rule_base_runtime.ReportPath = value

    @property
    def report_show_result(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReportShowResult() As CatShowResultType
                | 
                |     Returns or sets the option for sorting the report.
                | 
                |     0
                |         ByRule 
                |     1
                |         ByObject 
                |     2
                |         ByState

        :return: enum cat_show_result_type
        :rtype: int
        """

        return self.expert_rule_base_runtime.ReportShowResult

    @report_show_result.setter
    def report_show_result(self, value: int):
        """
        :param int value: enum cat_show_result_type
        """

        self.expert_rule_base_runtime.ReportShowResult = value

    @property
    def rule_base_edition(self) -> 'ExpertRuleBase':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RuleBaseEdition() As ExpertRuleBase (Read Only)
                | 
                |     Returns the editable object corresponding to this rulebase. Be careful
                |     that, according to your licence, or the type of rulebase you're handling, you
                |     may not have the right to edit the rulebase. 
                | Example:
                | 
                |      Dim aRBEdition As CATIAExpertRuleBase
                |      Set aRBEdition = aRBRuntime.RuleBaseEdition
                | 
                |      If not(aRBEdition is Nothing) Then
                |        ' .. action on the editable rulebase
                |      End if

        :rtype: ExpertRuleBase
        """

        from pycatia.general_knowledge_interfaces.expert_rule_base import ExpertRuleBase
        return ExpertRuleBase(self.expert_rule_base_runtime.RuleBaseEdition)

    @property
    def rule_set(self) -> ExpertRuleSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RuleSet() As ExpertRuleSet (Read Only)
                | 
                |     Returns the Set linked to the RuleBase. This is the main RuleSet that
                |     contains all the RuleBase components.

        :rtype: ExpertRuleSet
        """

        return ExpertRuleSet(self.expert_rule_base_runtime.RuleSet)

    @property
    def solve_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SolveType() As CatSolveType
                | 
                |     Returns or sets the solve option.

        :return: enum cat_solve_type
        :rtype: int
        """

        return self.expert_rule_base_runtime.SolveType

    @solve_type.setter
    def solve_type(self, value: int):
        """
        :param int value: enum cat_solve_type
        """

        self.expert_rule_base_runtime.SolveType = value

    @property
    def text_visualization(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TextVisualization() As CatVisualizationType
                | 
                |     Returns or sets the Report option for visualization.
                | 
                |     0
                |         Passed 
                |     1
                |         Failed 
                |     2
                |         Both

        :return: enum cat_visualization_type
        :rtype: int
        """

        return self.expert_rule_base_runtime.TextVisualization

    @text_visualization.setter
    def text_visualization(self, value: int):
        """
        :param int value: enum cat_visualization_type
        """

        self.expert_rule_base_runtime.TextVisualization = value

    def accurate_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AccurateType() As CATBSTR
                | 
                |     Returns as a string the type of component.
                | 
                |     Returns:
                |         A string among ("ExpertRuleBase", "ExpertRuleBaseRuntime")

        :rtype: str
        """
        return self.expert_rule_base_runtime.AccurateType()

    def add_fact(self, i_fact: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddFact(AnyObject iFact)
                | 
                |     Adds new fact to the rule base resolution.
                | 
                |     Parameters:
                | 
                |         iFact
                |             Fact to be added 
                | 
                |     Example:
                | 
                |           Dim pad3 as Shape
                |           Dim rulebase as ExpertRuleBase
                | 
                |           Set pad3 = part.MainBody.Shapes.Item("Pad3")
                |           Set rulebase = part.Relations.Item("RuleBase")
                |           rulebase.AddFact (pad3)

        :param AnyObject i_fact:
        :rtype: None
        """
        return self.expert_rule_base_runtime.AddFact(i_fact.com_object)

    def add_root_of_facts(self, i_root_facts: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddRootOfFacts(AnyObject iRootFacts)
                | 
                |     Adds a new root of facts to the rule base.
                | 
                |     Parameters:
                | 
                |         iRootFacts
                |             root of facts to be added.

        :param AnyObject i_root_facts:
        :rtype: None
        """
        return self.expert_rule_base_runtime.AddRootOfFacts(i_root_facts.com_object)

    def deduce(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Deduce()
                | 
                |     Launch a Forward chaining Solve on the current RuleBase. 
                | Example:
                | 
                |       Dim rulebase as ExpertRuleBase
                | 
                |       Set rulebase = part.Relations.Item("RuleBase")
                |       rulebase.Deduce ()

        :rtype: None
        """
        return self.expert_rule_base_runtime.Deduce()

    def fingerprint(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Fingerprint() As boolean
                | 
                |     Returns the Fingerprint information. The fingerprint indicates
                |     if the last result of the rulebase is relevant regarding to the
                |     objects the rule base has checked. In other words, if the part
                |     has evolved since last Deduce, the fingerprint is false.
                |     Be careful : on volatile rulebases ( ExpertRuleBase.VolatileCopy ), it raises an error.
                | 
                |     Example:
                | 
                |           on error resume next
                |           part.Relations.Item("RuleBase").Fingerprint ()
                |           on error goto 0
                |          
                | 
                |     Returns:
                |         Fingerprint information

        :rtype: bool
        """
        return self.expert_rule_base_runtime.Fingerprint()

    def get_number_of_roots_of_facts(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfRootsOfFacts() As long
                | 
                |     Retrieves the number of roots of facts of the rule base.
                | 
                |     Returns:
                |         Number of roots of facts.

        :rtype: int
        """
        return self.expert_rule_base_runtime.GetNumberOfRootsOfFacts()

    def get_roots_of_facts(self, o_roots_of_facts: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetRootsOfFacts(CATSafeArrayVariant oRootsOfFacts)
                | 
                |     Retrieves all the roots of facts from the rule base.
                | 
                |     Parameters:
                | 
                |         oRootsOfFacts
                |             array of roots of facts.

        :param tuple o_roots_of_facts:
        :rtype: None
        """
        return self.expert_rule_base_runtime.GetRootsOfFacts(o_roots_of_facts)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_roots_of_facts'
        # # vba_code = """
        # # Public Function get_roots_of_facts(expert_rule_base_runtime)
        # #     Dim oRootsOfFacts (2)
        # #     expert_rule_base_runtime.GetRootsOfFacts oRootsOfFacts
        # #     get_roots_of_facts = oRootsOfFacts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def import_(self, i_rule_set: ExpertRuleSet, i_force: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Import(ExpertRuleSet iRuleSet,
                | boolean iForce)
                | 
                |     Import from RuleSet.
                | 
                |     Parameters:
                | 
                |         iRuleSet
                |             CATIAExpertRuleSet : the RuleSet user want to import. 
                |         iForce
                |             Boolean : if True (= 1), then if imported rules allready exist in target document, rules of target document are replaced. 
                | 
                |     Example:
                | 
                |          Dim CATDocs As Documents
                |          Set CATDocs   = CATIA.Documents
                |          Dim partdoc As Document
                |          Set partdoc = CATDocs.Open("e:/TargetDocument.CATPart")
                |          Dim part As Part
                |          Set part      = partdoc.Part
                |          Dim productdoc As Document
                |          Set productdoc = CATDocs.Open("e:/ImportedDocument.CATProduct")
                |          Dim product As Product
                |          Set product      = productdoc.Product
                |          Dim ruleset As ExpertRuleSet
                |          Set ruleset    = product.Relations.Item("RuleBase").RuleSet.ExpertRuleBaseComponentRuntimes.ShallowItem(1)
                |          part.Relations.Item("RuleBase").Import (ruleset,0)

        :param ExpertRuleSet i_rule_set:
        :param bool i_force:
        :rtype: None
        """
        return self.expert_rule_base_runtime.Import(i_rule_set.com_object, i_force)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'import'
        # # vba_code = """
        # # Public Function import(expert_rule_base_runtime)
        # #     Dim iRuleSet (2)
        # #     expert_rule_base_runtime.Import iRuleSet
        # #     import = iRuleSet
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def import_from_file(self, i_path: str, i_force: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ImportFromFile(CATBSTR iPath,
                | boolean iForce)
                | 
                |     Import from file.
                | 
                |     Parameters:
                | 
                |         iPath
                |             CATBSTR : the path of the document user want to import. 
                |         iForce
                |             Boolean : if True (= 1), then if imported rules allready
                |             exist in target document, rules of target document are
                |             replaced. if False (= 0), then if imported rules allready
                |             exist in target document, rules of imported document are ignored.*
                |
                |     Example:
                | 
                |           part.Relations.Item("RuleBase").ImportFromFile
                |           ("e:/importeddocument.CATProduct",0)

        :param str i_path:
        :param bool i_force:
        :rtype: None
        """
        return self.expert_rule_base_runtime.ImportFromFile(i_path, i_force)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'import_from_file'
        # # vba_code = """
        # # Public Function import_from_file(expert_rule_base_runtime)
        # #     Dim iPath (2)
        # #     expert_rule_base_runtime.ImportFromFile iPath
        # #     import_from_file = iPath
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def import_with_link(self, i_root: AnyObject, i_force: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ImportWithLink(AnyObject iRoot,
                | boolean iForce)
                | 
                |     Import with link to a document.
                | 
                |     Parameters:
                | 
                |         iRoot
                |             CATIABase : the root user want to import into. 
                |         iForce
                |             Boolean : if True (= 1), then if imported rules allready exist
                |             in target document, rules of target document are replaced.
                |             if False (= 0), then if imported rules allready exist in
                |             target document, rules of imported document are ignored.*
                | 
                |     Example:
                | 
                |           part.Relations.Item("RuleBase").ImportWithLink
                |           (root,0)

        :param AnyObject i_root:
        :param bool i_force:
        :rtype: None
        """
        return self.expert_rule_base_runtime.ImportWithLink(i_root.com_object, i_force)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'import_with_link'
        # # vba_code = """
        # # Public Function import_with_link(expert_rule_base_runtime)
        # #     Dim iRoot (2)
        # #     expert_rule_base_runtime.ImportWithLink iRoot
        # #     import_with_link = iRoot
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_root_of_facts(self, i_root_facts: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveRootOfFacts(AnyObject iRootFacts)
                | 
                |     Removes a root of facts from the rule base.
                | 
                |     Parameters:
                | 
                |         iRootFacts
                |             root of facts to be removed.

        :param AnyObject i_root_facts:
        :rtype: None
        """
        return self.expert_rule_base_runtime.RemoveRootOfFacts(i_root_facts.com_object)

    def report(self, really_start_browser: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Report(boolean reallyStartBrowser)
                | 
                |     Launch a Report. The default output format is HTML
                | 
                |     Parameters:
                | 
                |         reallyStartBrowser
                |             Boolean : if True (= 1), then the browser is started on the report 
                | 
                |     Example:
                | 
                |           part.Relations.Item("RuleBase").Report (0)

        :param bool really_start_browser:
        :rtype: None
        """
        return self.expert_rule_base_runtime.Report(really_start_browser)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'report'
        # # vba_code = """
        # # Public Function report(expert_rule_base_runtime)
        # #     Dim reallyStartBrowser (2)
        # #     expert_rule_base_runtime.Report reallyStartBrowser
        # #     report = reallyStartBrowser
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def synchronize_status(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SynchronizeStatus() As boolean
                | 
                |     Returns the Synchronize information. The synchronize status indicates
                |     for a linked rule base if the rulebase is synchronized.
                |     Be careful : on volatile rulebases ( ExpertRuleBase.VolatileCopy ), it raises an error.
                | 
                |     Example:
                | 
                |           on error resume next
                |           part.Relations.Item("RuleBase").SynchronizeStatus ()
                |           on error goto 0
                |
                |     Returns:
                |         Synchronize status

        :rtype: bool
        """
        return self.expert_rule_base_runtime.SynchronizeStatus()

    def __repr__(self):
        return f'ExpertRuleBaseRuntime(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.manufacturing_interfaces.manufacturing_insert import ManufacturingInsert
from pycatia.manufacturing_interfaces.manufacturing_tool import ManufacturingTool
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingToolAssembly(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingToolAssembly
                | 
                | Represents the tool assembly.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_tool_assembly = com_object

    @property
    def assembly_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AssemblyType() As CATBSTR (Read Only)
                | 
                |     Returns the type of the tool assembly.
                |     Legal values: the type of the tool assembly can be either
                |     MfgMillAndDrillToolAssembly or MfgLatheToolAssembly.
                | 
                |     Example:
                | 
                |           The following example returns the assembly type Type of the assembly
                |           CurrentAssembly:
                |          
                | 
                |          Set Type=CurrentAssembly.AssemblyType

        :rtype: str
        """

        return self.manufacturing_tool_assembly.AssemblyType

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Comment() As CATBSTR (Read Only)
                | 
                |     Returns the default comment of a tool assembly.
                | 
                |     Example:
                | 
                |           The following example returns the comment Comment of the tool
                |           assembly CurrentAssembly:
                |          
                | 
                |          Comment=CurrentAssembly.Comment

        :rtype: str
        """

        return self.manufacturing_tool_assembly.Comment

    @property
    def insert(self) -> ManufacturingInsert:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Insert() As ManufacturingInsert (Read Only)
                | 
                |     Returns the insert of an assembly.
                | 
                |     Example:
                | 
                |           The following example retrieves in Insert the insert
                |           
                |          of the assembly CurrentAssembly:
                |          
                | 
                |          Set Insert = CurrentAssembly.Insert

        :rtype: ManufacturingInsert
        """

        return ManufacturingInsert(self.manufacturing_tool_assembly.Insert)

    @property
    def number_of_attributes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfAttributes() As short (Read Only)
                | 
                |     Returns the number of attributes of a tool assembly.
                | 
                |     Example:
                | 
                |           The following example returns the Number of attributes of the tool
                |           assembly CurrentAssembly:
                |          
                | 
                |          Number = CurrentAssembly.NumberOfAttributes

        :rtype: int
        """

        return self.manufacturing_tool_assembly.NumberOfAttributes

    @property
    def tool(self) -> ManufacturingTool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Tool() As ManufacturingTool (Read Only)
                | 
                |     Returns the tool of an assembly.
                | 
                |     Example:
                | 
                |           The following example retrieves in Tool the manufacturing tool
                |           
                |          of the assembly CurrentAssembly:
                |          
                | 
                |          Set Tool = CurrentAssembly.Tool

        :rtype: ManufacturingTool
        """

        return ManufacturingTool(self.manufacturing_tool_assembly.Tool)

    @property
    def tool_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ToolNumber() As long (Read Only)
                | 
                |     Returns the number linked to a tool assembly.
                | 
                |     Example:
                | 
                |           The following example returns the Number linked to the tool assembly
                |           CurrentAssembly:
                |          
                | 
                |          Number = CurrentAssembly.ToolNumber

        :rtype: int
        """

        return self.manufacturing_tool_assembly.ToolNumber

    def get_attribute(self, i_attribute: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttribute(CATBSTR iAttribute) As Parameter
                | 
                |     Returns an attribute of a tool assembly.
                |     The attribute is identified using its name, and is retrieved as a Parameter
                |     object.
                | 
                |     Parameters:
                | 
                |         iAttribute
                |             The attribute name 
                | 
                |     Returns:
                |         The retrieved attribute 
                |     Example:
                | 
                |           The following example retrieves in Diameter the attribute
                |           
                |          MfgDiameter of the tool assembly CurrentAssembly:
                |          
                | 
                |          Set Diameter = CurrentAssembly.GetAttribute(MfgDiameter)

        :param str i_attribute:
        :rtype: Parameter
        """
        return Parameter(self.manufacturing_tool_assembly.GetAttribute(i_attribute))

    def get_attribute_nls_name(self, i_attribute_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttributeNLSName(CATBSTR iAttributeName) As
                | CATBSTR
                | 
                |     Returns the NLS value of an attribute.
                | 
                |     Parameters:
                | 
                |         iAttributeName
                |             The attribute name 
                | 
                |     Returns:
                |         The attribute NLS value 
                |     Example:
                | 
                |           The following example gives in NLSresult the NLS value of the
                |           "MFG_COMMENT" attributes 
                |          of the tool assembly CurrentAssembly:
                |          
                | 
                |          NLSresult = CurrentAssembly.GetAttributeNLSName("MFG_COMMENT")

        :param str i_attribute_name:
        :rtype: str
        """
        return self.manufacturing_tool_assembly.GetAttributeNLSName(i_attribute_name)

    def get_list_of_attribute_units(self, io_list_of_attribute_units: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfAttributeUnits(CATSafeArrayVariant
                | ioListOfAttributeUnits)
                | 
                |     Retrieves the list of attribute units of a tool assembly.
                |     The number of items in the output array is equal to the number of
                |     attributes of the assembly. When an attribute has no unit definition, the
                |     corresponding unit item in the output array is a blank
                |     string.
                | 
                |     Parameters:
                | 
                |         ioListOfAttributeUnits
                |             The retrieved list of attributes units 
                | 
                |     Example:
                | 
                |           The following example retrieves in TabAttributeUnits the list of
                |           attribute units 
                |          of the tool assembly CurrentAssembly:
                |          
                | 
                |          call CurrentAssembly.GetListOfAttributeUnits(TabAttributeUnits)

        :param tuple io_list_of_attribute_units:
        :rtype: None
        """
        return self.manufacturing_tool_assembly.GetListOfAttributeUnits(io_list_of_attribute_units)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_attribute_units'
        # # vba_code = """
        # # Public Function get_list_of_attribute_units(manufacturing_tool_assembly)
        # #     Dim ioListOfAttributeUnits (2)
        # #     manufacturing_tool_assembly.GetListOfAttributeUnits ioListOfAttributeUnits
        # #     get_list_of_attribute_units = ioListOfAttributeUnits
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_attributes(self, io_list_of_attributes: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfAttributes(CATSafeArrayVariant
                | ioListOfAttributes)
                | 
                |     Retrieves the list of attributes of a tool assembly.
                |     Each attribute retrieved as a Parameter object.
                | 
                |     Parameters:
                | 
                |         ioListOfAttributes
                |             The retrieved list of attributes 
                | 
                |     Example:
                | 
                |           The following example retrieves in TabAttributes the list of
                |           attributes 
                |          of the tool assembly CurrentAssembly:
                |          
                | 
                |          call
                |          CurrentAssembly.GetListOfAttributes(TabAttributes)

        :param tuple io_list_of_attributes:
        :rtype: None
        """
        return self.manufacturing_tool_assembly.GetListOfAttributes(io_list_of_attributes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_attributes'
        # # vba_code = """
        # # Public Function get_list_of_attributes(manufacturing_tool_assembly)
        # #     Dim ioListOfAttributes (2)
        # #     manufacturing_tool_assembly.GetListOfAttributes ioListOfAttributes
        # #     get_list_of_attributes = ioListOfAttributes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ManufacturingToolAssembly(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_dpm_interfaces.mfg_assembly import MfgAssembly
from pycatia.dnb_human_sim_interfaces.worker_activity import WorkerActivity
from pycatia.product_structure_interfaces.product import Product


class PickActivity(WorkerActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DNBHumanSimInterfaces.WorkerActivity
                |                             PickActivity
                | 
                | The object that represents an PickActivity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pick_activity = com_object

    @property
    def pick_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PickType() As HTSPickType
                | 
                |     Returns or Sets "Pick Type" (see HTSPickType for list of possible values)
                |     SINGLE_HAND for Single-Handed Pick, BOTH_HANDS for Double-Handed Pick

        :return: enum hts_pick_type
        :rtype: int
        """

        return self.pick_activity.PickType

    @pick_type.setter
    def pick_type(self, value: int):
        """
        :param int value: enum hts_pick_type
        """

        self.pick_activity.PickType = value

    @property
    def picking_hand(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PickingHand() As HTSHand
                | 
                |     Returns or Sets "Picking Hand" (see HTSHand for list of possible values )

        :return: enum hts_hand
        :rtype: int
        """

        return self.pick_activity.PickingHand

    @picking_hand.setter
    def picking_hand(self, value: int):
        """
        :param int value: enum hts_hand
        """

        self.pick_activity.PickingHand = value

    def add_picked_mfg_assembly(self, p_picked_item: MfgAssembly) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPickedMfgAssembly(MfgAssembly pPickedItem)
                | 
                |     Adds a Manufacturing Assembly to the List of Picked Items (see MfgAssembly
                |     for list of possible values)

        :param MfgAssembly p_picked_item:
        :rtype: None
        """
        return self.pick_activity.AddPickedMfgAssembly(p_picked_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_picked_mfg_assembly'
        # # vba_code = """
        # # Public Function add_picked_mfg_assembly(pick_activity)
        # #     Dim pPickedItem (2)
        # #     pick_activity.AddPickedMfgAssembly pPickedItem
        # #     add_picked_mfg_assembly = pPickedItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_picked_product(self, p_picked_item: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPickedProduct(Product pPickedItem)
                | 
                |     Adds a product to the List of Picked Items

        :param Product p_picked_item:
        :rtype: None
        """
        return self.pick_activity.AddPickedProduct(p_picked_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_picked_product'
        # # vba_code = """
        # # Public Function add_picked_product(pick_activity)
        # #     Dim pPickedItem (2)
        # #     pick_activity.AddPickedProduct pPickedItem
        # #     add_picked_product = pPickedItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_picked_products(self, p_picked_prods: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPickedProducts(CATSafeArrayVariant pPickedProds)
                | 
                |     Returns or Sets Picked Products

        :param tuple p_picked_prods:
        :rtype: None
        """
        return self.pick_activity.GetPickedProducts(p_picked_prods)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_picked_products'
        # # vba_code = """
        # # Public Function get_picked_products(pick_activity)
        # #     Dim pPickedProds (2)
        # #     pick_activity.GetPickedProducts pPickedProds
        # #     get_picked_products = pPickedProds
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_picked_mfg_assembly(self, p_picked_item: MfgAssembly) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePickedMfgAssembly(MfgAssembly pPickedItem)
                | 
                |     Removes a Manufacturing Assembly from the list of Picked items (see
                |     MfgAssembly for list of possible values)

        :param MfgAssembly p_picked_item:
        :rtype: None
        """
        return self.pick_activity.RemovePickedMfgAssembly(p_picked_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_picked_mfg_assembly'
        # # vba_code = """
        # # Public Function remove_picked_mfg_assembly(pick_activity)
        # #     Dim pPickedItem (2)
        # #     pick_activity.RemovePickedMfgAssembly pPickedItem
        # #     remove_picked_mfg_assembly = pPickedItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_picked_product(self, p_picked_item: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePickedProduct(Product pPickedItem)
                | 
                |     Removes a product from the list of Picked items (see Product for list of
                |     possible values)

        :param Product p_picked_item:
        :rtype: None
        """
        return self.pick_activity.RemovePickedProduct(p_picked_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_picked_product'
        # # vba_code = """
        # # Public Function remove_picked_product(pick_activity)
        # #     Dim pPickedItem (2)
        # #     pick_activity.RemovePickedProduct pPickedItem
        # #     remove_picked_product = pPickedItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_picked_products(self, p_picked_prods: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPickedProducts(CATSafeArrayVariant pPickedProds)

        :param tuple p_picked_prods:
        :rtype: None
        """
        return self.pick_activity.SetPickedProducts(p_picked_prods)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_picked_products'
        # # vba_code = """
        # # Public Function set_picked_products(pick_activity)
        # #     Dim pPickedProds (2)
        # #     pick_activity.SetPickedProducts pPickedProds
        # #     set_picked_products = pPickedProds
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_place_act(self, place_act: Activity) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPlaceAct(Activity placeAct)
                | 
                |     Sets or append a link to a Place activity (see Activity for list of
                |     possible values)

        :param Activity place_act:
        :rtype: None
        """
        return self.pick_activity.SetPlaceAct(place_act.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_place_act'
        # # vba_code = """
        # # Public Function set_place_act(pick_activity)
        # #     Dim placeAct (2)
        # #     pick_activity.SetPlaceAct placeAct
        # #     set_place_act = placeAct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PickActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_data_output_requests import ABQDataOutputRequests
from pycatia.abq_automation_interfaces.abq_field_output_requests import ABQFieldOutputRequests
from pycatia.abq_automation_interfaces.abq_history_output_requests import ABQHistoryOutputRequests
from pycatia.abq_automation_interfaces.abq_interactions import ABQInteractions
from pycatia.system_interfaces.any_object import AnyObject


class ABQStep(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQStep
                | 
                | Represents a Abaqus analysis step (ABQStep) object.
                | Role: Access an Abaqus analysis step or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_step = com_object

    @property
    def data_output_requests(self) -> ABQDataOutputRequests:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DataOutputRequests() As ABQDataOutputRequests (Read
                | Only)
                | 
                |     Returns the ABQDataOutputRequests container associated with the
                |     step.
                | 
                |     Example:
                |         The following example retrieves the ABQDataOutputRequests container
                |         abqOutputRequests:
                | 
                |          Dim abqStep As ABQGeneralStaticStep 
                |          Dim abqDataOutputRequests As ABQDataOutputRequests
                |          Set abqDataOutputRequests = abqStep.OutputRequests

        :rtype: ABQDataOutputRequests
        """

        return ABQDataOutputRequests(self.abq_step.DataOutputRequests)

    @property
    def field_output_requests(self) -> ABQFieldOutputRequests:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FieldOutputRequests() As ABQFieldOutputRequests (Read
                | Only)
                | 
                |     Returns the ABQFieldOutputRequests container associated with the
                |     step.
                | 
                |     Example:
                |         The following example retrieves the ABQFieldOutputRequests container
                |         abqOutputRequests:
                | 
                |          Dim abqStep As ABQGeneralStaticStep 
                |          Dim abqFieldOutputRequests As ABQFieldOutputRequests
                |          Set abqFieldOutputRequests = abqStep.OutputRequests

        :rtype: ABQFieldOutputRequests
        """

        return ABQFieldOutputRequests(self.abq_step.FieldOutputRequests)

    @property
    def history_output_requests(self) -> ABQHistoryOutputRequests:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HistoryOutputRequests() As ABQHistoryOutputRequests (Read
                | Only)
                | 
                |     Returns the ABQHistoryOutputRequests container associated with the
                |     step.
                | 
                |     Example:
                |         The following example retrieves the ABQHistoryOutputRequests container
                |         abqOutputRequests:
                | 
                |          Dim abqStep As ABQGeneralStaticStep 
                |          Dim abqHistoryOutputRequests As
                |          ABQHistoryOutputRequests
                |          Set abqHistoryOutputRequests = abqStep.OutputRequests

        :rtype: ABQHistoryOutputRequests
        """

        return ABQHistoryOutputRequests(self.abq_step.HistoryOutputRequests)

    @property
    def interactions(self) -> ABQInteractions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Interactions() As ABQInteractions (Read Only)
                | 
                |     Returns the ABQInteractions container associated with the
                |     step.
                | 
                |     Example:
                |         The following example retrieves the ABQInteractions container
                |         abqInteractions:
                | 
                |          Dim abqStep As ABQGeneralStaticStep 
                |          Dim abqInteractions As ABQInteractions
                |          Set abqInteractions = abqStep.Interactions

        :rtype: ABQInteractions
        """

        return ABQInteractions(self.abq_step.Interactions)

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the step.
                | 
                |     Returns:
                |         The string representing the type of the step.

        :rtype: str
        """

        return self.abq_step.Type

    def __repr__(self):
        return f'ABQStep(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
from pycatia.cat_sch_platform_interfaces.sch_component import SchComponent
from pycatia.cat_sch_platform_interfaces.sch_grr import SchGRR
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.cat_sch_platform_interfaces.sch_route import SchRoute
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchAppComponent(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppComponent
                | 
                | Represents an application component object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_component = com_object

    def app_create_component_inst(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppCreateComponentInst() As AnyObject
                | 
                |     Create a component instance.
                | 
                |     Parameters:
                | 
                |         oNewAppCompInst
                |             Interface pointer (CATISchAppComponent) to the new application
                |             component instance placed. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim objArg1 As AnyObject
                |           ...
                |          Set objArg1 = objThisIntf.AppCreateComponentInst

        :rtype: AnyObject
        """
        return AnyObject(self.sch_app_component.AppCreateComponentInst())

    def app_create_local_reference(self, i_doc_to_copy_to: Document) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppCreateLocalReference(Document iDocToCopyTo) As
                | AnyObject
                | 
                |     Create Local Reference object. Given a reference object (the "this"), This
                |     method make a copy of the reference into another document.
                | 
                |     Parameters:
                | 
                |         iDocToCopyTo
                |             Pointer to a document to copy the reference to, 
                |         oNewAppCompRef
                |             Interface pointer (CATISchAppComponent) to the new application
                |             component Reference copied. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim objArg1 As Document
                |          Dim objArg2 As AnyObject
                |           ...
                |          Set objArg2 = objThisIntf.AppCreateLocalReference(objArg1)

        :param Document i_doc_to_copy_to:
        :rtype: AnyObject
        """
        return AnyObject(self.sch_app_component.AppCreateLocalReference(i_doc_to_copy_to.com_object))

    def app_get_default_grr_name(self, o_grr_default_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetDefaultGRRName(CATBSTR oGRRDefaultName)
                | 
                |     Get the default graphical representation names of an application
                |     component.
                | 
                |     Parameters:
                | 
                |         oGRRDefaultName
                |             The default name to be used for the graphical representation of a
                |             component 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.AppGetDefaultGRRNamestrVar1

        :param str o_grr_default_name:
        :rtype: None
        """
        return self.sch_app_component.AppGetDefaultGRRName(o_grr_default_name)

    def app_list_grr_names(self) -> SchListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppListGRRNames() As SchListOfBSTRs
                | 
                |     Find all the valid graphical representation names of an application
                |     component.
                | 
                |     Parameters:
                | 
                |         oLGRRNames
                |             A list of all the valid graphical representation names with this
                |             connector for connections. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim objArg1 As SchListOfBSTRs
                |           ...
                |          Set objArg1 = objThisIntf.AppListGRRNames

        :rtype: SchListOfBSTRs
        """
        return SchListOfBSTRs(self.sch_app_component.AppListGRRNames())

    def app_ok_to_flip_connected(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToFlipConnected(boolean oBYes)
                | 
                |     Query whether it is OK to reconnect a component to a different compatible
                |     configuration.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to flip the component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppComponent
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToFlipConnectedbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_component.AppOKToFlipConnected(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_flip_connected'
        # # vba_code = """
        # # Public Function app_ok_to_flip_connected(sch_app_component)
        # #     Dim oBYes (2)
        # #     sch_app_component.AppOKToFlipConnected oBYes
        # #     app_ok_to_flip_connected = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_flip_horizontal(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToFlipHorizontal(boolean oBYes)
                | 
                |     Query whether it is OK to flip the application component about
                |     Y.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to flip the component. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToFlipHorizontalbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_component.AppOKToFlipHorizontal(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_flip_horizontal'
        # # vba_code = """
        # # Public Function app_ok_to_flip_horizontal(sch_app_component)
        # #     Dim oBYes (2)
        # #     sch_app_component.AppOKToFlipHorizontal oBYes
        # #     app_ok_to_flip_horizontal = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_flip_on_line(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToFlipOnLine(boolean oBYes)
                | 
                |     Query whether it is OK to flip a component about its inserted
                |     line.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to flip the component. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToFlipOnLinebVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_component.AppOKToFlipOnLine(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_flip_on_line'
        # # vba_code = """
        # # Public Function app_ok_to_flip_on_line(sch_app_component)
        # #     Dim oBYes (2)
        # #     sch_app_component.AppOKToFlipOnLine oBYes
        # #     app_ok_to_flip_on_line = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_flip_vertical(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToFlipVertical(boolean oBYes)
                | 
                |     Query whether it is OK to flip the application component about
                |     X.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to flip the component. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToFlipVerticalbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_component.AppOKToFlipVertical(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_flip_vertical'
        # # vba_code = """
        # # Public Function app_ok_to_flip_vertical(sch_app_component)
        # #     Dim oBYes (2)
        # #     sch_app_component.AppOKToFlipVertical oBYes
        # #     app_ok_to_flip_vertical = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_place_in_space(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToPlaceInSpace(boolean oBYes)
                | 
                |     Query whether the application component can be placed in free
                |     space.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, the component can be slided. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToPlaceInSpacebVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_component.AppOKToPlaceInSpace(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_place_in_space'
        # # vba_code = """
        # # Public Function app_ok_to_place_in_space(sch_app_component)
        # #     Dim oBYes (2)
        # #     sch_app_component.AppOKToPlaceInSpace oBYes
        # #     app_ok_to_place_in_space = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_scale(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToScale(boolean oBYes)
                | 
                |     Query whether it is OK to scale the application component.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to scale the component. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToScalebVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_component.AppOKToScale(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_scale'
        # # vba_code = """
        # # Public Function app_ok_to_scale(sch_app_component)
        # #     Dim oBYes (2)
        # #     sch_app_component.AppOKToScale oBYes
        # #     app_ok_to_scale = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_slide(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToSlide(boolean oBYes)
                | 
                |     Query whether the application component can be slided.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, the component can be slided. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToSlidebVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_component.AppOKToSlide(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_slide'
        # # vba_code = """
        # # Public Function app_ok_to_slide(sch_app_component)
        # #     Dim oBYes (2)
        # #     sch_app_component.AppOKToSlide oBYes
        # #     app_ok_to_slide = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_uninsert(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToUninsert(boolean oBYes)
                | 
                |     Query whether it is OK to uninsert the application
                |     component.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to uninsert the component. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToUninsertbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_component.AppOKToUninsert(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_uninsert'
        # # vba_code = """
        # # Public Function app_ok_to_uninsert(sch_app_component)
        # #     Dim oBYes (2)
        # #     sch_app_component.AppOKToUninsert oBYes
        # #     app_ok_to_uninsert = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_post_flip_connected_process(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostFlipConnectedProcess()
                | 
                |     Post process after reconnecting a component to a different compatible
                |     configuration.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |           ...
                |          objThisIntf.AppPostFlipConnectedProcess

        :rtype: None
        """
        return self.sch_app_component.AppPostFlipConnectedProcess()

    def app_post_flip_horizontal_process(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostFlipHorizontalProcess()
                | 
                |     Post process after flipping a component in "x".
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |           ...
                |          objThisIntf.AppPostFlipHorizontalProcess

        :rtype: None
        """
        return self.sch_app_component.AppPostFlipHorizontalProcess()

    def app_post_flip_on_line_process(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostFlipOnLineProcess()
                | 
                |     Post process after flipping an inserted component about the inserted line
                |     segment of the route.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |           ...
                |          objThisIntf.AppPostFlipOnLineProcess

        :rtype: None
        """
        return self.sch_app_component.AppPostFlipOnLineProcess()

    def app_post_flip_vertical_process(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostFlipVerticalProcess()
                | 
                |     Post process after flipping a component in "y".
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |           ...
                |          objThisIntf.AppPostFlipVerticalProcess

        :rtype: None
        """
        return self.sch_app_component.AppPostFlipVerticalProcess()

    def app_post_place_process(
            self,
            i_new_comp_inst: SchComponent,
            i_cntbl_connected_to: SchAppConnectable
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostPlaceProcess(SchComponent iNewCompInst,
                | SchAppConnectable iCntblConnectedTo)
                | 
                |     Post process after placing an application component
                |     instance.
                | 
                |     Parameters:
                | 
                |         iNewCompInst
                |             The newly placed component instance (CATISchComponent interface
                |             pointer). 
                |         iCntbleConnectedTo
                |             The connectable that the placed component is connected to or placed
                |             onto 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim objArg1 As SchComponent
                |          Dim objArg2 As SchAppConnectable
                |           ...
                |          objThisIntf.AppPostPlaceProcessobjArg1,objArg2

        :param SchComponent i_new_comp_inst:
        :param SchAppConnectable i_cntbl_connected_to:
        :rtype: None
        """
        return self.sch_app_component.AppPostPlaceProcess(i_new_comp_inst.com_object, i_cntbl_connected_to.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_post_place_process'
        # # vba_code = """
        # # Public Function app_post_place_process(sch_app_component)
        # #     Dim iNewCompInst (2)
        # #     sch_app_component.AppPostPlaceProcess iNewCompInst
        # #     app_post_place_process = iNewCompInst
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_post_slide_process(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostSlideProcess()
                | 
                |     Post process after sliding a component.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |           ...
                |          objThisIntf.AppPostSlideProcess

        :rtype: None
        """
        return self.sch_app_component.AppPostSlideProcess()

    def app_post_switch_graphic_process(self, i_grr: SchGRR) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostSwitchGraphicProcess(SchGRR iGRR)
                | 
                |     Post process after switching a component's graphic
                |     representation.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim objArg1 As SchGRR
                |           ...
                |          objThisIntf.AppPostSwitchGraphicProcessobjArg1

        :param SchGRR i_grr:
        :rtype: None
        """
        return self.sch_app_component.AppPostSwitchGraphicProcess(i_grr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_post_switch_graphic_process'
        # # vba_code = """
        # # Public Function app_post_switch_graphic_process(sch_app_component)
        # #     Dim iGRR (2)
        # #     sch_app_component.AppPostSwitchGraphicProcess iGRR
        # #     app_post_switch_graphic_process = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_post_uninsert_process(
            self,
            i_old_app_route1: SchRoute,
            i_old_app_route2: SchRoute,
            i_new_app_route: SchRoute
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostUninsertProcess(SchRoute iOldAppRoute1,
                | SchRoute iOldAppRoute2,
                | SchRoute iNewAppRoute)
                | 
                |     Post process after uninserting a component, disconnecting it from a
                |     route.
                | 
                |     Parameters:
                | 
                |         iOldAppRoute1
                |             One of the route that was connected to one connector of the
                |             inserted component before the operation. 
                |         iOldAppRoute2
                |             The other route that was connected to the other connector of the
                |             inserted component before the operation. This would be NULL if the component
                |             was connected at extremity. 
                |         iNewAppRoute
                |             The new route created after the operation. This would be NULL if
                |             the component was connected at extremity. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppComponent
                |          Dim objArg1 As SchRoute
                |          Dim objArg2 As SchRoute
                |          Dim objArg3 As SchRoute
                |           ...
                |          objThisIntf.AppPostUninsertProcessobjArg1,objArg2,objArg3

        :param SchRoute i_old_app_route1:
        :param SchRoute i_old_app_route2:
        :param SchRoute i_new_app_route:
        :rtype: None
        """
        return self.sch_app_component.AppPostUninsertProcess(
            i_old_app_route1.com_object,
            i_old_app_route2.com_object,
            i_new_app_route.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_post_uninsert_process'
        # # vba_code = """
        # # Public Function app_post_uninsert_process(sch_app_component)
        # #     Dim iOldAppRoute1 (2)
        # #     sch_app_component.AppPostUninsertProcess iOldAppRoute1
        # #     app_post_uninsert_process = iOldAppRoute1
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppComponent(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_property import ABQProperty
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication


class ABQPretensionProperty(ABQProperty):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQProperty
                |                         ABQPretensionProperty
                | 
                | Represents a pretension property (ABQPretensionProperty)
                | object.
                | Role: Access an Abaqus pretension property.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_pretension_property = com_object

    def add_support_from_product(self, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromProduct(Product iProduct,
                | Reference iSupport)
                | 
                |     Creates a new support and adds it to the description of the bolt pretension
                |     property.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the bolt
                |             pretension property is applied.
                |         iSupport
                |             The CATIA Reference specifying the region to which the bolt
                |             pretension property is applied.
                | 
                |             Refer: CATIAReference, CATIAProduct

        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_pretension_property.AddSupportFromProduct(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_product'
        # # vba_code = """
        # # Public Function add_support_from_product(abq_pretension_property)
        # #     Dim iProduct (2)
        # #     abq_pretension_property.AddSupportFromProduct iProduct
        # #     add_support_from_product = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Creates a new support and adds it to the description of the bolt pretension
                |     property.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the bolt
                |             pretension property is applied.
                |         iPublication
                |             The CATIA Publication specifying the region to which the bolt
                |             pretension property is applied.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_pretension_property.AddSupportFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(abq_pretension_property)
        # #     Dim iProduct (2)
        # #     abq_pretension_property.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_reference: Reference, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Reference iReference,
                | Reference iSupport)
                | 
                |     Creates a new support and adds it to the description of the bolt pretension
                |     property.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The CATIA Reference specifying the object to which the bolt
                |             pretension property is applied.
                |         iSupport
                |             The CATIA Reference specifying the region to which the bolt
                |             pretension property is applied.
                | 
                |             Refer: CATIAReference

        :param Reference i_reference:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_pretension_property.AddSupportFromReference(i_reference.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(abq_pretension_property)
        # #     Dim iReference (2)
        # #     abq_pretension_property.AddSupportFromReference iReference
        # #     add_support_from_reference = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def clear_cutting_plane(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ClearCuttingPlane()
                | 
                |     Clears the cutting plane.

        :rtype: None
        """
        return self.abq_pretension_property.ClearCuttingPlane()

    def set_cutting_plane(self, i_product: Reference, i_ref: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCuttingPlane(Reference iProduct,
                | Reference iRef)
                | 
                |     Sets the cutting plane for the bolt pretension property. Cutting plane will
                |     be needed in case user wants to model pretension in 3D bolt. Any previously set
                |     plane will be replaced with this new value.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product for the plane. 
                |         iRef
                |             The reference to the plane.

        :param Reference i_product:
        :param Reference i_ref:
        :rtype: None
        """
        return self.abq_pretension_property.SetCuttingPlane(i_product.com_object, i_ref.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_cutting_plane'
        # # vba_code = """
        # # Public Function set_cutting_plane(abq_pretension_property)
        # #     Dim iProduct (2)
        # #     abq_pretension_property.SetCuttingPlane iProduct
        # #     set_cutting_plane = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQPretensionProperty(name="{self.name}")'
